@@ -45,6 +45,7 @@
 #include <thread>
 #include <tuple>
 #include <type_traits>
+#include <unordered_map>
 #include <utility>
 
 #include "config.h"
@@ -460,8 +461,10 @@ class LogCleaner {
   bool enabled_{false};
   std::chrono::minutes overdue_{
       std::chrono::duration<int, std::ratio<kSecondsInWeek>>{1}};
-  std::chrono::system_clock::time_point
-      next_cleanup_time_;  // cycle count at which to clean overdue log
+  // Maintain a separate cycle count for cleaning overdue logs for each
+  // base_filename.
+  std::unordered_map<std::string, std::chrono::system_clock::time_point>
+      next_cleanup_time_;
 };
 
 LogCleaner log_cleaner;
@@ -507,8 +510,8 @@ class LogDestination {
   // Use untimed shared mutex
   using SinkMutex = std::shared_mutex;
   using SinkLock = std::lock_guard<SinkMutex>;
-#else  // !(defined(__cpp_lib_shared_mutex) && (__cpp_lib_shared_mutex >=
-       // 201505L)) Fallback to timed shared mutex
+#else   // !(defined(__cpp_lib_shared_mutex) && (__cpp_lib_shared_mutex >=
+        // 201505L)) Fallback to timed shared mutex
   using SinkMutex = std::shared_timed_mutex;
   using SinkLock = std::unique_lock<SinkMutex>;
 #endif  // defined(__cpp_lib_shared_mutex) && (__cpp_lib_shared_mutex >=
@@ -1306,12 +1309,17 @@ void LogCleaner::Run(const std::chrono::system_clock::time_point& current_time,
   assert(enabled_);
   assert(!base_filename_selected || !base_filename.empty());
 
+  auto next_cleanup_time =
+      next_cleanup_time_
+          .emplace(base_filename, std::chrono::system_clock::time_point{})
+          .first->second;
+
   // avoid scanning logs too frequently
-  if (current_time < next_cleanup_time_) {
+  if (current_time < next_cleanup_time) {
     return;
   }
 
-  next_cleanup_time_ =
+  next_cleanup_time_[base_filename] =
       current_time +
       std::chrono::duration_cast<std::chrono::system_clock::duration>(
           std::chrono::duration<int32>{FLAGS_logcleansecs});
@@ -1979,7 +1987,7 @@ int64 LogMessage::num_messages(int severity) {
 // Output the COUNTER value. This is only valid if ostream is a
 // LogStream.
 ostream& operator<<(ostream& os, const Counter_t&) {
-#ifdef DISABLE_RTTI
+#if !defined(__GXX_RTTI) && !defined(_CPPRTTI)
   LogMessage::LogStream* log = static_cast<LogMessage::LogStream*>(&os);
 #else
   auto* log = dynamic_cast<LogMessage::LogStream*>(&os);
@@ -2414,9 +2422,9 @@ void TruncateLogFile(const char* path, uint64 limit, uint64 keep) {
   }
   if (bytesin == -1) PLOG(ERROR) << "Unable to read from " << path;
 
-    // Truncate the remainder of the file. If someone else writes to the
-    // end of the file after our last read() above, we lose their latest
-    // data. Too bad ...
+  // Truncate the remainder of the file. If someone else writes to the
+  // end of the file after our last read() above, we lose their latest
+  // data. Too bad ...
 #  ifdef HAVE__CHSIZE_S
   if (_chsize_s(fd.get(), write_offset) != 0) {
 #  else
