@@ -1497,8 +1497,9 @@ TEST(TestExitOnDFatal, ToBeOrNotToBe) {
 
 #  ifdef GTEST_HAS_DEATH_TEST
   // Death comes on little cats' feet.
-  EXPECT_DEBUG_DEATH({ LOG(DFATAL) << "This should be fatal in debug mode"; },
-                     "This should be fatal in debug mode");
+  EXPECT_DEBUG_DEATH(
+      { LOG(DFATAL) << "This should be fatal in debug mode"; },
+      "This should be fatal in debug mode");
 #  endif
 }
 
